import { DashboardService } from './../../../shared/dashboard.service';
import { MainMenuService } from './../../../shared/main-menu.service';
import { Component, OnInit } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { AuthServiceService } from './../../../shared/auth-service.service';
import { ActivatedRoute, Router, Params } from '@angular/router';
import { UserService } from '../../../shared/user.service';
import { NgxSpinnerService } from 'ngx-spinner';
import { ToastrService } from 'ngx-toastr';
import { Overlay } from 'ngx-modialog';
import { Modal } from 'ngx-modialog/plugins/bootstrap';

@Component({
  selector: 'app-absorpation-list',
  templateUrl: './absorpation-list.component.html',
  styleUrls: ['./absorpation-list.component.css']
})
export class AbsorpationListComponent implements OnInit {

  pageId: number;
  absorpationList = [];
  absorpationListIds = [];
  count: number;
  perPagePagenation: number;
  p: number[] = [];
  currentPage:number = 1;
  filtterStatus = '';
  selectedAll: any;
  userLoginId:number;
  serviceId:number;
  dataTableNumber: number = 5;
  pages = [];
  servicesName: string = '';

  constructor(private route: ActivatedRoute, 
    private router: Router, 
    private userSer: UserService,
    private http: HttpClient,
    private toastr: ToastrService,
    private spinner: NgxSpinnerService,
    private modal: Modal,
    private dashBoardService: DashboardService,
    private authSer: AuthServiceService) { }

  ngOnInit() {
    
    this.spinner.show();
    //init the values of permision boolean
    this.authSer.showAddBtn = false;
    this.authSer.showDeleteBtn = false;
    this.authSer.showEditBtn = false;
    //show / hide notification search in header
    this.authSer.notificationLogin = true;
    this.authSer.showSearchHeader = false;
    this.authSer.showHeaderLogin = false;
    this.authSer.showHeaderDashBoard = true;
    this.authSer.showDashboardHeader = true;
    this.authSer.internalHeader = false;

    
    
   
    this.route.params.subscribe(
      (params: Params) => {
        this.pageId = params['listPageId'];
        localStorage.setItem('pageIdActive', params['listPageId']);
      }
    );
    
    //to show / hide permissions

  this.route.parent.params.subscribe(
    (params:Params) => {
        this.userLoginId = params['userID'];
        this.serviceId = params['serviceID'];
        this.servicesName = 'خدمه التدريب';

        this.userSer.getPagesPermetiotns(this.userLoginId, this.serviceId).subscribe(
          (responce) => {
            console.log(responce);
            this.pages = responce['pages'];
            for(let i = 0; i< this.pages.length; i++) {
              if(this.pages[i].id == 34) {
                if(this.pages[i]['permissions'][0].name == 'absorption_plan') {
                  this.authSer.showAddBtn = true;
                  this.authSer.showEditBtn = true;
                  this.authSer.showDeleteBtn = true;
                } else {
                  console.log('no permissions');
                }
              } else {
                console.log('no events');
              }
            }
            this.spinner.hide();
          },
          (error) => {console.log(error)}
        );
      }

    );

    //get list data 
    this.dashBoardService.getListData(this.pageId, this.currentPage ,this.dataTableNumber).subscribe(
      (responce) => {
        console.log(responce);
        this.absorpationList = responce['absorption_plans'];
        this.count = responce['count'];
        this.perPagePagenation = responce['per_page'];
        console.log('evennnnts', this.absorpationList);
        this.spinner.hide();
      },
      (error) => {
        console.log(error);
        this.spinner.hide();
      }
    );
    
  }

  //make all checkbox of user checked 
  selectAll() {
    for (var i = 0; i < this.absorpationList.length; i++) {
      this.absorpationList[i].selected = this.selectedAll;
    }
  }

  checkIfAllSelected() {
    this.selectedAll = this.absorpationList.every(function(item:any) {
      return item.selected == true;
    });
  }

  //filtter function
  filtterFunc(data) {
    this.absorpationList = [];
    console.log(data.target.value);
    const dataSearch = data.target.value;     
    this.currentPage = 1;
    console.log('search curent page', this.currentPage);
    console.log('search page id', this.pageId);
    this.dashBoardService.getDataUSerSearchBar(dataSearch, this.pageId, this.currentPage, this.dataTableNumber).subscribe(
      (responce) => {
        console.log(responce);
        this.absorpationList = responce['absorption_plans'];
        this.count = responce['count'];
        this.perPagePagenation = responce['per_page'];
        console.log('filtter count', this.count);
        console.log('filtter perPagePAgenation', this.perPagePagenation);
      },
      (error) => {
        console.log(error)
      }
    );
  };

  //change pagenation
  onPageChange(pagenationNumber) {
    this.spinner.show();
    this.currentPage = pagenationNumber;
    this.absorpationList = [];
    //console.log(pagenationNumber);
    //console.log(this.pageId);
    this.dashBoardService.getListData(this.pageId, pagenationNumber, this.dataTableNumber).subscribe(
      (responce) => {
        console.log(responce);
        this.absorpationList = responce['absorption_plans'];
        this.count = responce['count'];
        this.perPagePagenation = responce['per_page'];
        console.log(this.absorpationList);
        this.spinner.hide();
      },
      (error) => {
        console.log(error);
        this.spinner.hide();
      }
    );
  }



  //determine the list count from select element 
  onGetValue(event) {
    this.spinner.show();
    this.absorpationList = [];
    this.dataTableNumber = event.target.value;
    this.dashBoardService.getListData(this.pageId, this.currentPage, this.dataTableNumber).subscribe(
      (responce) => {
        console.log(responce);
        this.absorpationList = responce['absorption_plans'];
        this.count = responce['count'];
        this.perPagePagenation = responce['per_page'];
        this.spinner.hide();
      },
      (error) => {
        console.log(error);
        this.spinner.hide();
      }
    );
  };
  
  onDelete() {

    this.absorpationListIds = [];
    for(let i = 0; i < this.absorpationList.length; i++) {
      if(this.absorpationList[i].selected == true) {
        this.absorpationListIds.push(this.absorpationList[i].id);
      }
    }

    console.log(this.absorpationListIds);
    if(this.absorpationListIds.length > 0) {
      const dialogRef = this.modal.alert()
      .size('sm')
      .showClose(true)
      .title('تأكيد الحذف')
      .body(`
          <h4>هل ترغب في حذف العناصر المحدده ؟ </h4>
          `)
      .open();
  
        dialogRef.result
        .then( result => 
          this.dashBoardService.deleteItem(this.absorpationListIds, this.pageId).subscribe(
              (responce) => {
                console.log(responce);
                this.toastr.success('تم الحذف');
                this.spinner.show();
                this.absorpationList = [];
                this.dashBoardService.getListData(this.pageId, this.currentPage, this.dataTableNumber).subscribe(
                  (responce) => {
                    console.log(responce);
                    this.count = responce['count'];
                    this.perPagePagenation = responce['per_page'];
                    this.absorpationList = responce['absorption_plans'];
                    console.log(this.absorpationList);
                    this.spinner.hide();
                  },
                  (error) => {
                    console.log(error);
                  }
                )
              },
              (error) => {
                console.log(error);
                this.toastr.error('حدث خطأ رجاء الانتظار وحاول ثانيه');
                this.spinner.hide();
              }
          )
        );
    } else {
      this.toastr.warning('لم يتم أختيار أي عنصر للحذف !');
    }
  };

  //add function
  onAdd() {
    console.log('service/' + this.userLoginId + '/' + this.serviceId + '/absorpation/Add');
    this.router.navigate(['service/' + this.userLoginId + '/' + this.serviceId + '/absorpation/Add']);
  }

  //edit function
   onEdit(editId) {
    this.router.navigate(['service/' + this.userLoginId + '/' + this.serviceId + '/absorpation/edit/' + editId]);
  }

}
